==> kbibtex-trinity_14.0.5.orig.tar.xz: kbibtex-trinity-14.0.5/src/commentwidget.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef COMMENTWIDGET_H
#define COMMENTWIDGET_H

#include <ntqwidget.h>
#include <ntqdialog.h>

#include <comment.h>

class TQMultiLineEdit;
class TQCheckBox;

namespace KBibTeX
{
    class CommentWidget : public TQWidget
    {
        Q_OBJECT
    public:
        CommentWidget( BibTeX::Comment *comment, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
        ~CommentWidget();

        static TQDialog::DialogCode execute( BibTeX::Comment *comment, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );

    private:
        BibTeX::Comment* m_comment;
        TQCheckBox *m_checkboxUseCommand;
        TQMultiLineEdit *m_multiLineEdit;
        bool m_isReadOnly;

        void setupGUI();
        void setCommentData();
        void getCommentData();
    };

}

#endif

==> kbibtex-trinity-14.0.9.tar.xz: kbibtex-trinity-14.0.9/src/commentwidget.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef COMMENTWIDGET_H
#define COMMENTWIDGET_H

#include <tqwidget.h>
#include <tqdialog.h>

#include "comment.h"

class TQMultiLineEdit;
class TQCheckBox;

namespace KBibTeX
{
    class CommentWidget : public TQWidget
    {
        Q_OBJECT
    public:
        CommentWidget( BibTeX::Comment *comment, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
        ~CommentWidget();

        static TQDialog::DialogCode execute( BibTeX::Comment *comment, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );

    private:
        BibTeX::Comment* m_comment;
        TQCheckBox *m_checkboxUseCommand;
        TQMultiLineEdit *m_multiLineEdit;
        bool m_isReadOnly;

        void setupGUI();
        void setCommentData();
        void getCommentData();
    };

}

#endif
